@@ -2,7 +2,7 @@ package Resource::Silo::Container;
 
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -154,11 +154,11 @@ sub _instantiate_resource {
     local $self->{-pending}{$key} = 1;
 
     foreach my $mod (@{ $spec->{require} }) {
-        local $@;
-        eval { load $mod; 1; }
-            or croak "Failed to load '$mod' via resource '$name': $@";
+        eval { load $mod; 1 }
+            or croak "resource '$name': failed to load '$mod': $@";
     };
-    ($self->{-override}{$name} // $spec->{init})->($self, $name, $arg);
+    ($self->{-override}{$name} // $spec->{init})->($self, $name, $arg)
+        // croak "Fetching resource '$key' failed for no apparent reason";
 };
 
 # use instead of delete $self->{-cache}{$name}
