@@ -2,7 +2,7 @@ package Resource::Silo::Metadata;
 
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -270,21 +270,14 @@ sub self_check {
     foreach my $name (sort keys %$res) {
         my $entry = $res->{$name};
 
-        my @missing_deps = grep { !$res->{$_} } keys %{ $entry->{allowdeps} };
+        my @missing_deps = grep { !$res->{$_} } keys %{ $entry->{allowdeps} || {} };
         croak "resource '$name': missing dependencies: ".
             join ", ", map { "'$_'" } @missing_deps
                 if @missing_deps;
 
-        local $@;
-        my $mod;
-        eval {
-            foreach ( @{ $entry->{require} } ) {
-                $mod = $_;
-                load $mod;
-            };
-            1;
-        } || do {
-            croak "resource '$name': failed to load required module '$mod': $@";
+        foreach my $mod ( @{ $entry->{require} } ) {
+            eval { load $mod; 1 }
+                or croak "resource '$name': failed to load '$mod': $@";
         };
     };
 
